use actix_identity::Identity;
use actix_web::{http::header::LOCATION, web, HttpMessage, HttpRequest, HttpResponse, Responder};
use serde::Deserialize;
use sqlx::PgPool;

use crate::{auth::utils::hash_plain_password_with_salt, models::user::User};

#[derive(Deserialize)]
struct LoginForm {
    email: String,
    password: String,
}

#[actix_web::post("/login")]
async fn route(
    web::Form(form): web::Form<LoginForm>,
    request: HttpRequest,
    pool: web::Data<PgPool>,
) -> impl Responder {

    if let Ok(result) = User::read_for_login(pool.get_ref(), &form.email).await {
        if let Some(user) = result {
            let hash = hash_plain_password_with_salt(&form.password, &user.salt).unwrap();
            if hash == user.password {
                Identity::login(&request.extensions(), user.id.to_string()).unwrap();

                return HttpResponse::Found().insert_header((LOCATION, "/")).finish();
            } else {
                return HttpResponse::Unauthorized().body("Nutzername oder Passwort falsch.");
            }
        } else {
            return HttpResponse::Unauthorized().body("Nutzername oder Passwort falsch.");
        }
    } else {
        return HttpResponse::Unauthorized().body("Nutzername oder Passwort falsch.");
    }
}
