use actix_identity::Identity;
use actix_web::{http::header::LOCATION, web, HttpResponse, Responder};
use chrono::{NaiveDate, NaiveTime};
use serde::Deserialize;
use sqlx::PgPool;

use crate::models::{availabillity::Availabillity, user::User};

#[derive(Deserialize)]
pub struct AvailabillityForm {
    date: NaiveDate,
    start_time: Option<NaiveTime>,
    end_time: Option<NaiveTime>,
    comment: Option<String>
}

#[actix_web::post("/availabillity/new")]
pub async fn post_availabillity(
    user: Identity,
    pool: web::Data<PgPool>,
    form: web::Form<AvailabillityForm>,
) -> impl Responder {
    let current_user = User::read_by_id(pool.as_ref(), user.id().unwrap().parse().unwrap())
        .await
        .unwrap();

    if let Ok(_) = Availabillity::create(pool.get_ref(), current_user.id, form.date, form.start_time, form.end_time, form.comment.clone()).await {
        HttpResponse::Found()
            .insert_header((LOCATION, "/"))
            .finish()
    } else {
        HttpResponse::BadRequest().body("Fehler beim erstellen")
    }
}
