use chrono::{NaiveDate, NaiveTime};
use sqlx::{query, PgPool};

use super::user::User;

pub struct Availabillity {
    pub id: i32,
    pub user_id: i32,
    pub user: Option<User>,
    pub date: NaiveDate,
    pub start_time: Option<NaiveTime>,
    pub end_time: Option<NaiveTime>,
    pub comment: Option<String>,
}

impl Availabillity {
    pub async fn create(
        pool: &PgPool,
        user_id: i32,
        date: NaiveDate,
        start_time: Option<NaiveTime>,
        end_time: Option<NaiveTime>,
        comment: Option<String>,
    ) -> anyhow::Result<i32> {
        let result = match (start_time, end_time, comment) {
            (Some(start_time), Some(end_time), Some(comment)) => query!("INSERT INTO availabillity (userId, date, startTime, endTime, comment) VALUES ($1, $2, $3, $4, $5) RETURNING id;", user_id, date, start_time, end_time, comment).fetch_one(pool).await?.id,
            (Some(start_time), Some(end_time), None) => query!("INSERT INTO availabillity (userId, date, startTime, endTime) VALUES ($1, $2, $3, $4) RETURNING id;", user_id, date, start_time, end_time).fetch_one(pool).await?.id,
            (None, None, Some(comment)) => query!("INSERT INTO availabillity (userId, date, comment) VALUES ($1, $2, $3) RETURNING id;", user_id, date, comment).fetch_one(pool).await?.id,
            (_, _, _) => query!("INSERT INTO availabillity (userId, date) VALUES ($1, $2) RETURNING id;", user_id, date).fetch_one(pool).await?.id
        };

        Ok(result)
    }

    pub async fn read_by_date(
        pool: &PgPool,
        date: NaiveDate,
    ) -> anyhow::Result<Vec<Availabillity>> {
        let records = query!("SELECT * FROM availabillity WHERE date = $1", date)
            .fetch_all(pool)
            .await?;

        let availabillities = records
            .iter()
            .map(|a| Availabillity {
                id: a.id,
                user_id: a.userid,
                user: None,
                date: a.date,
                start_time: a.starttime,
                end_time: a.endtime,
                comment: a.comment.clone(),
            })
            .collect();

        Ok(availabillities)
    }

    pub async fn load_user(&mut self, pool: &PgPool) -> anyhow::Result<()> {
        let user = User::read_by_id(pool, self.user_id).await?;
        self.user = Some(user);

        Ok(())
    }
}
