use sqlx::{query, PgPool};

pub struct Location {
    pub id: i32,
    pub name: String,
    pub area_id: i32,
}

impl Location {
    pub async fn create(pool: &PgPool, name: &str, area_id: i32) -> anyhow::Result<i32> {
        let result = query!(
            "INSERT INTO location (name, areaId) VALUES ($1, $2) RETURNING id;",
            name,
            area_id
        )
        .fetch_one(pool)
        .await?;

        Ok(result.id)
    }

    pub async fn read_by_area(pool: &PgPool, area_id: i32) -> anyhow::Result<Vec<Location>> {
        let records = query!("SELECT * FROM location WHERE areaId = $1;", area_id)
            .fetch_all(pool)
            .await?;

        let locations = records
            .iter()
            .map(|lr| Location {
                id: lr.id,
                name: lr.name.to_string(),
                area_id: lr.areaid,
            })
            .collect();

        Ok(locations)
    }
}
